/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.alarm;

import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldNameConstants;
import org.hibernate.annotations.Comment;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.annotations.Where;
import org.hibernate.snowflake.SnowflakeId;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.annotation.LastModifiedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/27 11:20
 */
@Getter
@Setter
@ToString
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@Entity
@Where(clause = "deleted = false")
@Table(name = "BS_Alarm_Type")
@Comment("报警类型信息")
@EntityListeners(AuditingEntityListener.class)
public class AlarmType implements Serializable {

    @Serial
    private static final long serialVersionUID = -735021155587741700L;

    @Id
    @Comment("主键id")
    @GeneratedValue(generator = SnowflakeId.GENERATOR)
    @GenericGenerator(name = SnowflakeId.GENERATOR, strategy = SnowflakeId.Strategy.LONG)
    private Long id;

    @Comment("报警类型名称")
    private String name;

    @Comment("围栏类型")
    private Integer fenceType;

    @Comment("关联参数类型")
    private Integer relevanceParam;

    @Comment("备注")
    private String comment;

    @Comment("创建时间")
    @CreatedDate
    @Column(nullable = false)
    private LocalDateTime createTime;

    @Comment("最后修改时间")
    @LastModifiedDate
    @Column(nullable = false)
    private LocalDateTime lastUpdateTime;

    @Comment(value = "是否删除")
    @Column(nullable = false)
    private Boolean deleted;
}
