/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.rehearsal;

import com.yiring.app.domain.video.Video;
import com.yiring.common.domain.BasicEntity;
import java.io.Serial;
import java.io.Serializable;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldNameConstants;
import lombok.experimental.SuperBuilder;
import org.hibernate.annotations.Comment;
import org.hibernate.annotations.Type;
import org.hibernate.annotations.Where;
import org.locationtech.jts.geom.Geometry;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/7 10:16
 */
@Getter
@Setter
@ToString
@SuperBuilder(toBuilder = true)
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@Entity
@Where(clause = "deleted = false")
@Table(name = "BS_ACCIDENT_SPOT")
@Comment("事故点信息")
@EntityListeners(AuditingEntityListener.class)
public class AccidentSpot extends BasicEntity implements Serializable {

    @Serial
    private static final long serialVersionUID = 3599118033272730887L;

    @Comment("事故点名称")
    private String name;

    @Comment("地图id")
    private Long mapId;

    @Comment("地图名称")
    private String mapName;

    @Comment("空间信息")
    @Type(type = "jts_geometry")
    @Column(columnDefinition = "geometry")
    private Geometry geometry;

    @Comment("摄像头")
    @ManyToOne
    @JoinColumn(name = "video_id")
    private Video video;

    @Comment("超时时间(秒)")
    private Integer timeoutDuration;

    @Comment("消抖时间(秒)")
    private Integer threshold;

    @Comment("是否启用")
    private Boolean enable;

    @Comment(value = "是否删除")
    @Column(nullable = false)
    private Boolean deleted;
}
