/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.rehearsal;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;
import java.util.Set;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/7 10:24
 */
@Repository
public interface AccidentSpotRepository
    extends JpaRepository<AccidentSpot, Serializable>, JpaSpecificationExecutor<AccidentSpot> {
    /**
     * 查询名称是否存在
     * @param name 事故点名称
     * @return true:存在 false:不存在
     */
    Boolean existsByName(String name);

    /**
     * 根据名称查询所有事故点
     * @param name 事故点名称
     * @return 事故点信息
     */
    List<AccidentSpot> findAllByName(String name);

    /**
     * 根据名称全模糊查询
     * @param name 名称
     * @return 事故点信息
     */
    @Query("SELECT a FROM AccidentSpot a WHERE a.name like %?1% AND a.deleted = false")
    List<AccidentSpot> findLikeName(String name);

    /**
     * 批量删除
     * @param ids id集
     * @param now 当前时间
     * @return 删除了几条数据
     */
    @Query("UPDATE AccidentSpot SET deleted = true, updateTime = :now WHERE id IN (:ids)")
    int batchRemove(@Param("ids") Set<Long> ids, @Param("now") LocalDateTime now);

    /**
     * 批量启用/停用
     * @param ids 事故点id集
     * @param now 当前时间
     * @param enable true:启用 false:停用
     * @return 启用/停用了多少条数据
     */
    @Query("UPDATE AccidentSpot SET enable = :enable ,updateTime = :now WHERE id IN (:ids) AND deleted = false")
    @Modifying
    int batchEnable(@Param("ids") Set<Long> ids, @Param("enable") boolean enable, @Param("now") LocalDateTime now);
}
