/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.rehearsal;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.List;
import java.util.Set;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/9 9:19
 */
@Repository
public interface EvacuationZoneRepository
    extends JpaRepository<EvacuationZone, Serializable>, JpaSpecificationExecutor<EvacuationZone> {
    /**
     * 判断名称是否存在
     * @param name 撤离区名称
     * @return true:存在 false:不存在
     */
    boolean existsByName(String name);

    /**
     * 根据名称查询
     * @param name 撤离区名称
     * @return 撤离区列表
     */
    List<EvacuationZone> findAllByName(String name);

    /**
     * 批量删除
     * @param ids id集
     * @param now 当前时间
     * @return 删除了多少条
     */
    @Query("UPDATE EvacuationZone SET deleted = true, updateTime = :now WHERE id in (:ids)")
    @Modifying
    int removeMany(@Param("ids") Set<Long> ids, @Param("now") LocalDateTime now);

    /**
     * 名称模糊查询撤离区
     * @param name 名称
     * @return  撤离区列表
     */
    @Query("SELECT e FROM EvacuationZone e WHERE e.deleted = false AND e.name like %?1%")
    List<EvacuationZone> findLikeName(String name);

    /**
     * 批量启用或停用撤离区
     * @param enable 启用或停用
     * @param ids 撤离区id集
     * @param now 当前时间
     * @return 改变了几条
     */
    @Query("UPDATE EvacuationZone SET enable = :enable, updateTime = :now WHERE id in (:ids) AND deleted = false")
    @Modifying
    int changeEnable(@Param("enable") boolean enable, @Param("ids") Set<Long> ids, @Param("now") LocalDateTime now);
}
