/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.rehearsal;

import com.yiring.common.domain.BasicEntity;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.persistence.Entity;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import lombok.experimental.FieldNameConstants;
import lombok.experimental.SuperBuilder;
import org.hibernate.annotations.Comment;
import org.hibernate.annotations.Where;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/9 17:07
 */
@Getter
@Setter
@NoArgsConstructor
@AllArgsConstructor
@Entity
@FieldNameConstants
@SuperBuilder(toBuilder = true)
@Where(clause = "deleted = false")
@Table(name = "BS_REHEARSAL_PLAN")
@Comment("演练计划信息")
public class RehearsalPlan extends BasicEntity implements Serializable {

    @Serial
    private static final long serialVersionUID = -5215681932640062553L;

    @Comment("演练主题")
    private String topical;

    @Comment("事故点")
    @ManyToOne
    @JoinColumn(name = "accident_spot_id")
    private AccidentSpot accidentSpot;

    @Comment("周边范围(事故点周围多少米)")
    private Integer scope;

    @Comment("撤离区")
    @ManyToOne
    @JoinColumn(name = "evacuation_zone_id")
    private EvacuationZone evacuationZone;

    @Comment("风险程度(1:红色风险, 2:橙色风险, 3:黄色风险, 4:蓝色风险)")
    private Integer riskLevel;

    @Comment("事故信息")
    private String accidentMsg;

    @Comment("演练时间")
    private LocalDateTime rehearsalTime;

    @Comment("推送信息")
    private String pushMsg;

    @Comment("演练计划的状态(1:未启动, 2:进行中, 3:已结束)")
    private Integer status;

    @Comment("逻辑删除")
    private boolean deleted;
}
