/* (C) 2022 YiRing, Inc. */
package com.yiring.app.excel.dept;

import cn.hutool.core.util.ObjectUtil;
import com.github.liaochong.myexcel.core.annotation.ExcelColumn;
import com.github.liaochong.myexcel.core.annotation.ExcelModel;
import com.yiring.auth.domain.dept.Department;
import java.io.Serial;
import java.io.Serializable;
import lombok.AccessLevel;
import lombok.Builder;
import lombok.Data;
import lombok.experimental.FieldDefaults;

/**
 * 部门导出
 *
 * @author LJ-2204
 * @date 2022/4/22
 */

@ExcelModel
@Data
@Builder
@FieldDefaults(level = AccessLevel.PRIVATE)
public class DepartmentExportExcel implements Serializable {

    @Serial
    private static final long serialVersionUID = 6268534775569565860L;

    @ExcelColumn(title = "部门名称")
    String name;

    @ExcelColumn(title = "负责人")
    String realName;

    @ExcelColumn(title = "手机号码")
    String mobile;

    @ExcelColumn(title = "状态")
    String enable;

    public static DepartmentExportExcel transform(Department department) {
        DepartmentExportExcel departmentExportExcel = DepartmentExportExcel
            .builder()
            .name(department.getName())
            .enable(ObjectUtil.equals(department.getEnable(), true) ? "启用" : "禁用")
            .build();
        if (ObjectUtil.isNotEmpty(department.getLeader())) {
            departmentExportExcel.setRealName(department.getLeader().getRealName());
            departmentExportExcel.setMobile(department.getLeader().getMobile());
        }

        return departmentExportExcel;
    }
}
