/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.broadcast;

import com.yiring.app.domain.broadcast.BroadcastAudio;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotEmpty;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 播报音频
 *
 * @author LJ-2204
 * @date 2022/5/7
 */

@ApiModel("BroadcastAudioAddParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class BroadcastAudioAddParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 7174160141071642430L;

    @ApiModelProperty(value = "语音名称", example = "警告张三", required = true)
    @NotEmpty(message = "语音名称不能为空")
    String name;

    @ApiModelProperty(value = "语音地址", example = "uri", required = true)
    @NotEmpty(message = "语音地址不能为空")
    String uri;

    @ApiModelProperty(value = "备注", example = "请输入备注信息")
    String describe;

    public static BroadcastAudio transform(BroadcastAudioAddParam param) {
        return BroadcastAudio.builder().name(param.getName()).uri(param.getUri()).describe(param.getDescribe()).build();
    }
}
