/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.dept;

import cn.hutool.core.date.LocalDateTimeUtil;
import cn.hutool.core.util.ObjectUtil;
import com.yiring.auth.domain.dept.Department;
import com.yiring.auth.domain.user.User;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotNull;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 部门修改入参
 *
 * @author LJ-2204
 * @date 2022/4/24
 */

@ApiModel("DepartmentModifyParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class DepartmentModifyParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 8839239258775446219L;

    @ApiModelProperty(value = "主键", example = "1", required = true)
    @NotNull
    Long id;

    @ApiModelProperty(value = "上级部门", example = "1", required = true)
    @NotNull
    Long pid;

    @ApiModelProperty(value = "名称", example = "Java", required = true)
    @NotNull
    String name;

    @ApiModelProperty(value = "负责人", example = "1")
    Long leaderId;

    @ApiModelProperty(value = "部门状态", example = "T/F")
    Boolean enable;

    public void transform(DepartmentModifyParam departmentModifyParam, Department department) {
        department.setPid(departmentModifyParam.getPid());
        department.setName(departmentModifyParam.getName());
        if (ObjectUtil.isNotEmpty(departmentModifyParam.getLeaderId())) {
            department.setLeader(User.builder().id(departmentModifyParam.getLeaderId()).build());
        }
        department.setUpdateTime(LocalDateTimeUtil.now());
        department.setEnable(departmentModifyParam.getEnable());
    }
}
