/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.rehearsal;

import com.yiring.app.domain.rehearsal.AccidentSpot;
import com.yiring.app.domain.video.Video;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import javax.validation.constraints.NotNull;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.locationtech.jts.geom.Geometry;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/7 10:59
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@ApiModel("添加事故点参数")
public class AccidentSpotModifyParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 5678801405341645678L;

    @ApiModelProperty(value = "事故点id", example = "1", required = true)
    @NotNull(message = "请选择一个事故点id")
    private Long id;

    @ApiModelProperty(value = "事故点名称", example = "事故点1", required = true)
    private String name;

    @ApiModelProperty(value = "地图id", example = "1", required = true)
    private Long mapId;

    @ApiModelProperty(value = "地图名称", example = "总图", required = true)
    private String mapName;

    @ApiModelProperty(value = "空间信息")
    private Geometry geometry;

    @ApiModelProperty(value = "摄像头id", example = "1")
    private Long videoId;

    @ApiModelProperty(value = "超时时间(秒)", example = "100", required = true)
    private Integer timeoutDuration;

    @ApiModelProperty(value = "消抖时间(秒)", example = "100", required = true)
    private Integer threshold;

    public AccidentSpot transform() {
        Video video = Video.builder().id(videoId).build();
        return AccidentSpot
            .builder()
            .id(id)
            .name(name)
            .mapId(mapId)
            .mapName(mapName)
            .geometry(geometry)
            .video(video)
            .timeoutDuration(timeoutDuration)
            .threshold(threshold)
            .enable(false)
            .deleted(false)
            .build();
    }
}
