/* (C) 2022 YiRing, Inc. */
package com.yiring.app.param.rehearsal;

import com.yiring.app.domain.rehearsal.EvacuationZone;
import com.yiring.app.domain.video.Video;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.locationtech.jts.geom.Geometry;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/9 9:29
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@ApiModel("撤离区修改param")
public class EvacuationZoneModifyParam implements Serializable {

    @Serial
    private static final long serialVersionUID = -7802093296111267529L;

    @ApiModelProperty(value = "撤离区id", example = "1", required = true)
    private Long id;

    @ApiModelProperty(value = "撤离区名称", example = "撤离区1")
    private String name;

    @ApiModelProperty(value = "地图id", example = "1")
    private Long mapId;

    @ApiModelProperty(value = "地图名称", example = "总图")
    private String mapName;

    @ApiModelProperty(value = "空间信息")
    private Geometry geometry;

    @ApiModelProperty(value = "摄像头id", example = "1519550823770624000")
    private Long videoId;

    @ApiModelProperty(value = "超时时间(秒)", example = "20")
    private Integer timeoutDuration;

    @ApiModelProperty(value = "消抖时间(秒)", example = "10")
    private Integer threshold;

    public EvacuationZone transform() {
        Video video = Video.builder().id(videoId).build();
        return EvacuationZone
            .builder()
            .id(id)
            .name(name)
            .mapId(mapId)
            .mapName(mapName)
            .geometry(geometry)
            .video(video)
            .timeoutDuration(timeoutDuration)
            .threshold(threshold)
            .enable(false)
            .deleted(false)
            .build();
    }
}
