/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.broadcast.impl;

import cn.hutool.core.collection.ListUtil;
import cn.hutool.core.util.ObjectUtil;
import com.yiring.app.domain.broadcast.BroadcastAudio;
import com.yiring.app.domain.broadcast.BroadcastAudioRepository;
import com.yiring.app.param.broadcast.BroadcastAudioAddParam;
import com.yiring.app.param.broadcast.BroadcastAudioFindParam;
import com.yiring.app.param.broadcast.BroadcastAudioModifyParam;
import com.yiring.app.service.broadcast.BroadcastAudioService;
import com.yiring.app.vo.broadcast.BroadcastAudioIndexVo;
import com.yiring.app.vo.broadcast.BroadcastAudioVo;
import com.yiring.common.core.Result;
import com.yiring.common.core.Status;
import com.yiring.common.domain.BasicEntity;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.IndexParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import java.util.List;
import java.util.Optional;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import javax.persistence.criteria.Order;
import javax.persistence.criteria.Predicate;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * 播报音频
 *
 * @author LJ-2204
 * @date 2022/5/7
 */

@Slf4j
@Transactional(rollbackFor = RuntimeException.class)
@Service
public class BroadcastAudioServiceImpl implements BroadcastAudioService {

    @Resource
    BroadcastAudioRepository broadcastAudioRepository;

    @Override
    public Result<String> save(BroadcastAudioAddParam param) {
        broadcastAudioRepository.save(BroadcastAudioAddParam.transform(param));
        return Result.ok();
    }

    @Override
    public Result<String> delete(IdParam idParam) {
        Optional<BroadcastAudio> byId = broadcastAudioRepository.findById(idParam.getId());
        if (byId.isEmpty()) return Result.no(Status.BAD_REQUEST, "信息不存在");

        BroadcastAudio broadcastAudio = byId.get();
        broadcastAudioRepository.delete(broadcastAudio);
        return Result.ok();
    }

    @Override
    public Result<String> modify(BroadcastAudioModifyParam param) {
        Optional<BroadcastAudio> byId = broadcastAudioRepository.findById(param.getId());
        if (byId.isEmpty()) return Result.no(Status.BAD_REQUEST, "信息不存在");

        BroadcastAudio broadcastAudio = byId.get();
        broadcastAudio.setDescribe(param.getDescribe());
        broadcastAudio.setName(param.getName());
        broadcastAudio.setUri(param.getUri());
        broadcastAudioRepository.save(broadcastAudio);
        return Result.ok();
    }

    @Override
    public Result<PageVo<BroadcastAudioVo>> page(BroadcastAudioFindParam param, PageParam pageParam) {
        Specification<BroadcastAudio> specification = (root, cq, cb) -> {
            List<Predicate> predicates = ListUtil.toList();

            if (ObjectUtil.isNotEmpty(param.getName())) {
                predicates.add(cb.like(root.get(BroadcastAudio.Fields.name), "%" + param.getName() + "%"));
            }
            Order order = cb.desc(root.get(BasicEntity.Fields.createTime));
            return cq.orderBy(order).where(predicates.toArray(new Predicate[0])).getRestriction();
        };

        // 分页
        Pageable pageable = PageRequest.of(pageParam.getPageNo() - 1, pageParam.getPageSize());

        Page<BroadcastAudio> broadcastAudios = broadcastAudioRepository.findAll(specification, pageable);
        List<BroadcastAudioVo> broadcastAudioVos = broadcastAudios
            .getContent()
            .stream()
            .map(BroadcastAudioVo::transform)
            .collect(Collectors.toList());
        PageVo<BroadcastAudioVo> pageVo = PageVo.build(broadcastAudioVos, broadcastAudios.getTotalElements());
        return Result.ok(pageVo);
    }

    @Override
    public Result<PageVo<BroadcastAudioIndexVo>> index(IndexParam indexParam) {
        Specification<BroadcastAudio> specification = (root, cq, cb) -> {
            List<Predicate> predicates = ListUtil.toList();

            if (ObjectUtil.isNotEmpty(indexParam.getStr())) {
                predicates.add(cb.like(root.get(BroadcastAudio.Fields.name), "%" + indexParam.getStr() + "%"));
            }
            Order order = cb.desc(root.get(BasicEntity.Fields.createTime));
            return cq.orderBy(order).where(predicates.toArray(new Predicate[0])).getRestriction();
        };

        List<BroadcastAudio> broadcastAudios = broadcastAudioRepository.findAll(specification);
        List<BroadcastAudioIndexVo> broadcastAudioIndexVos = broadcastAudios
            .stream()
            .map(BroadcastAudioIndexVo::transform)
            .collect(Collectors.toList());
        PageVo<BroadcastAudioIndexVo> pageVo = PageVo.build(broadcastAudioIndexVos, broadcastAudioIndexVos.size());

        return Result.ok(pageVo);
    }
}
