/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.key.impl;

import cn.hutool.core.collection.ListUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.yiring.app.domain.key.KeyAlarm;
import com.yiring.app.domain.key.KeyAlarmRepository;
import com.yiring.app.domain.key.KeyAlarmRules;
import com.yiring.app.domain.key.KeyAlarmRulesRepository;
import com.yiring.app.param.key.KeyAlarmFindParam;
import com.yiring.app.service.key.KeyAlarmService;
import com.yiring.app.vo.key.KeyAlarmVo;
import com.yiring.app.vo.user.UserVo;
import com.yiring.auth.domain.user.User;
import com.yiring.common.core.Result;
import com.yiring.common.domain.BasicEntity;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import java.util.List;
import java.util.Optional;
import java.util.Set;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import javax.persistence.criteria.Order;
import javax.persistence.criteria.Predicate;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * 按键报警
 *
 * @author LJ-2204
 * @date 2022/5/10
 */

@Transactional(rollbackFor = RuntimeException.class)
@Service
@Slf4j
public class KeyAlarmServiceImpl implements KeyAlarmService {

    @Resource
    KeyAlarmRepository keyAlarmRepository;

    @Resource
    KeyAlarmRulesRepository keyAlarmRulesRepository;

    @Override
    public Result<PageVo<KeyAlarmVo>> page(KeyAlarmFindParam param, PageParam pageParam) {
        Specification<KeyAlarm> specification = (root, cq, cb) -> {
            List<Predicate> predicates = ListUtil.toList();

            if (ObjectUtil.isNotEmpty(param.getAreaId())) {
                predicates.add(cb.equal(root.get(KeyAlarm.Fields.areaId), param.getAreaId()));
            }

            if (ObjectUtil.isNotEmpty(param.getName())) {
                predicates.add(
                    cb.like(root.get(KeyAlarm.Fields.leader).get(User.Fields.realName), "%" + param.getName() + "%")
                );
            }

            if (ObjectUtil.isNotEmpty(param.getEnable())) {
                predicates.add(cb.equal(root.get(KeyAlarm.Fields.enable), param.getEnable()));
            }

            if (ObjectUtil.isNotEmpty(param.getCreateTime())) {
                predicates.add(cb.lessThan(root.get(BasicEntity.Fields.createTime), param.getCreateTime()));
            }

            if (ObjectUtil.isNotEmpty(param.getEndTime())) {
                predicates.add(cb.greaterThan(root.get(BasicEntity.Fields.updateTime), param.getEndTime()));
            }

            Order order = cb.desc(root.get(BasicEntity.Fields.createTime));

            return cq.orderBy(order).where(predicates.toArray(new Predicate[0])).getRestriction();
        };

        Pageable pageable = PageRequest.of(pageParam.getPageNo() - 1, pageParam.getPageSize());
        Page<KeyAlarm> keyAlarms = keyAlarmRepository.findAll(specification, pageable);
        List<KeyAlarmVo> keyAlarmVos = keyAlarms
            .getContent()
            .stream()
            .map(keyAlarm -> {
                KeyAlarmVo keyAlarmVo = KeyAlarmVo.transform(keyAlarm);
                User leader = keyAlarm.getLeader();

                if (ObjectUtil.isNotEmpty(leader)) {
                    UserVo userVo = UserVo
                        .builder()
                        .id(leader.getId())
                        .realName(leader.getRealName())
                        .uuid(leader.getUuid())
                        .departmentId(leader.getDepartment().getId())
                        .build();
                    keyAlarmVo.setUser(userVo);
                }
                Optional<KeyAlarmRules> keyAlarmRulesOptional = keyAlarmRulesRepository.findById(
                    leader.getDepartment().getId()
                );

                if (keyAlarmRulesOptional.isPresent()) {
                    KeyAlarmRules keyAlarmRules = keyAlarmRulesOptional.get();
                    Set<User> users = keyAlarmRules.getUsers();
                    List<String> names = users.stream().map(User::getRealName).collect(Collectors.toList());
                    keyAlarmVo.setReceiver(StrUtil.join(",", names));
                }
                return keyAlarmVo;
            })
            .collect(Collectors.toList());

        PageVo<KeyAlarmVo> pageVo = PageVo.build(keyAlarmVos, keyAlarms.getTotalElements());

        return Result.ok(pageVo);
    }
}
