/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.location.beacon.impl;

import cn.hutool.core.collection.ListUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.github.liaochong.myexcel.core.DefaultStreamExcelBuilder;
import com.yiring.app.domain.location.LocationBeacon;
import com.yiring.app.domain.location.LocationBeaconRepository;
import com.yiring.app.excel.location.beacon.LocationBeaconExportExcel;
import com.yiring.app.feign.zy.location.beacon.LocationBeaconClient;
import com.yiring.app.param.location.beacon.LocationBeaconAddParam;
import com.yiring.app.param.location.beacon.LocationBeaconExportParam;
import com.yiring.app.param.location.beacon.LocationBeaconFindParam;
import com.yiring.app.service.location.beacon.LocationBeaconService;
import com.yiring.app.util.GeoUtils;
import com.yiring.app.util.zy.ZyUtil;
import com.yiring.app.vo.location.beacon.LocationBeaconVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;
import java.util.HashMap;
import java.util.List;
import java.util.Optional;
import java.util.concurrent.Executors;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import javax.persistence.criteria.Order;
import javax.persistence.criteria.Predicate;
import javax.servlet.http.HttpServletResponse;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * 定位信标
 *
 * @author LJ-2204
 * @date 2022/4/28
 */

@Transactional(rollbackFor = RuntimeException.class)
@Service
@Slf4j
public class LocationBeaconServiceImpl implements LocationBeaconService {

    @Resource
    LocationBeaconClient locationTagBeaconClient;

    @Resource
    LocationBeaconRepository locationBeaconRepository;

    @Override
    public void saveLocationBeacon() {
        HashMap<String, Object> hashMap = new HashMap<>();
        hashMap.put("deviceType", "BTI");
        hashMap.put("pageSize", 100);
        hashMap.put("pageNum", 0);
        hashMap.put("orgId", 100);
        hashMap.put("deviceId", "");
        JSONObject jsonObject = locationTagBeaconClient.page(JSONUtil.toJsonStr(hashMap), ZyUtil.manageLogin());
        JSONObject data = JSONUtil.parseObj(jsonObject.get("data"));
        JSONArray records = JSONUtil.parseArray(data.get("records"));
        List<LocationBeaconAddParam> locationBeaconAddParams = JSONUtil.toList(
            JSONUtil.toJsonStr(records),
            LocationBeaconAddParam.class
        );

        locationBeaconAddParams.forEach(locationBeaconAddParam -> {
            Optional<LocationBeacon> locationBeaconOptional = locationBeaconRepository.findOne(
                Example.of(
                    LocationBeacon
                        .builder()
                        .code(locationBeaconAddParam.getDeviceId())
                        .linkId(locationBeaconAddParam.getId())
                        .build()
                )
            );

            if (locationBeaconOptional.isEmpty()) {
                LocationBeacon locationBeacon = LocationBeaconAddParam.transform(locationBeaconAddParam);
                locationBeaconRepository.save(locationBeacon);
            } else {
                LocationBeacon locationBeacon = locationBeaconOptional.get();
                modifyLocationBeacon(locationBeacon, locationBeaconAddParam);
            }
        });
    }

    @Override
    public Result<PageVo<LocationBeaconVo>> findLocationBeacon(
        LocationBeaconFindParam locationBeaconFindParam,
        PageParam pageParam
    ) {
        Specification<LocationBeacon> specification = (root, cq, cb) -> {
            List<Predicate> predicates = ListUtil.toList();

            if (StrUtil.isNotEmpty(locationBeaconFindParam.getCode())) {
                predicates.add(
                    cb.like(root.get(LocationBeacon.Fields.code), "%" + locationBeaconFindParam.getCode() + "%")
                );
            }

            Order order = cb.desc(root.get(LocationBeacon.Fields.time));

            return cq.orderBy(order).where(predicates.toArray(new Predicate[0])).getRestriction();
        };

        Pageable pageable = PageRequest.of(pageParam.getPageNo() - 1, pageParam.getPageSize());
        Page<LocationBeacon> locationBeacons = locationBeaconRepository.findAll(specification, pageable);
        List<LocationBeaconVo> locationBeaconVos = locationBeacons
            .stream()
            .map(LocationBeaconVo::transform)
            .collect(Collectors.toList());
        PageVo<LocationBeaconVo> pageVo = PageVo.build(locationBeaconVos, locationBeacons.getTotalElements());
        return Result.ok(pageVo);
    }

    @Override
    public void exportLocationBeacon(
        LocationBeaconExportParam locationBeaconExportParam,
        HttpServletResponse response
    ) {
        Specification<LocationBeacon> specification = (root, cq, cb) -> {
            List<Predicate> predicates = ListUtil.toList();

            if (StrUtil.isNotEmpty(locationBeaconExportParam.getCode())) {
                predicates.add(
                    cb.like(root.get(LocationBeacon.Fields.code), "%" + locationBeaconExportParam.getCode() + "%")
                );
            }

            Order order = cb.desc(root.get(LocationBeacon.Fields.time));

            return cq.orderBy(order).where(predicates.toArray(new Predicate[0])).getRestriction();
        };

        List<LocationBeacon> locationBeacons = locationBeaconRepository.findAll(specification);
        List<LocationBeaconExportExcel> locationBeaconExportExcels = locationBeacons
            .stream()
            .map(LocationBeaconExportExcel::transform)
            .collect(Collectors.toList());
        try (
            DefaultStreamExcelBuilder<LocationBeaconExportExcel> streamExcelBuilder = DefaultStreamExcelBuilder
                .of(LocationBeaconExportExcel.class)
                .threadPool(Executors.newFixedThreadPool(2))
                .rowHeight(14)
                .titleRowHeight(14)
                .style(
                    "cell->vertical-align:center;text-align:center",
                    "title->vertical-align:center;text-align:center;font-weight:bold;font-family:等线"
                )
                .start()
        ) {
            streamExcelBuilder.append(locationBeaconExportExcels);

            String fileName = URLEncoder.encode("信标信息.xlsx", StandardCharsets.UTF_8);
            response.setContentType("application/octet-stream");
            response.setHeader("Access-Control-Expose-Headers", "Content-Disposition");
            response.setHeader("Content-Disposition", "attachment;filename=" + fileName);
            OutputStream out = response.getOutputStream();

            Workbook workbook = streamExcelBuilder.fixedTitles().build();
            workbook.write(out);
            workbook.close();
            out.flush();
            out.close();
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            throw new RuntimeException("导出信标信息失败: " + e.getMessage());
        }
    }

    private void modifyLocationBeacon(LocationBeacon locationBeacon, LocationBeaconAddParam locationBeaconAddParam) {
        locationBeacon.setCode(locationBeaconAddParam.getDeviceId());
        locationBeacon.setAreaId(locationBeaconAddParam.getAreaId());
        locationBeacon.setLinkId(locationBeaconAddParam.getId());
        locationBeacon.setX(locationBeaconAddParam.getX());
        locationBeacon.setY(locationBeaconAddParam.getY());
        locationBeacon.setZ(locationBeaconAddParam.getZ());
        locationBeacon.setTime(locationBeaconAddParam.getTime());
        locationBeacon.setVolt(locationBeaconAddParam.getVolt());
        locationBeacon.setVoltUnit(locationBeaconAddParam.getVoltUnit());
        locationBeacon.setPoint(
            GeoUtils.xyzToPoint(
                locationBeaconAddParam.getX().doubleValue(),
                locationBeaconAddParam.getY().doubleValue(),
                locationBeaconAddParam.getZ().doubleValue()
            )
        );
    }
}
