/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.rehearsal;

import com.yiring.app.param.rehearsal.AccidentSpotAddParam;
import com.yiring.app.param.rehearsal.AccidentSpotConditionParam;
import com.yiring.app.param.rehearsal.AccidentSpotModifyParam;
import com.yiring.app.vo.IdNameVo;
import com.yiring.app.vo.rehearsal.AccidentSpotVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import java.util.Set;
import javax.validation.Valid;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/7 13:45
 */
public interface AccidentSpotService {
    /**
     * 添加一个事故点
     * @param param 事故点信息
     * @return 是否成功
     */
    Result<String> addAccidentSpot(AccidentSpotAddParam param);

    /**
     * 修改一个事故点
     * @param param 事故点信息
     * @return 是否成功
     */
    Result<String> modifyAccidentSpot(AccidentSpotModifyParam param);

    /**
     * 删除一个事故点
     * @param param id
     * @return 是否成功
     */
    Result<String> removeAccidentSpot(IdParam param);

    /**
     * 批量删除事故点
     * @param ids 事故点id集
     * @return 是否成功
     */
    Result<String> batchRemove(Set<Long> ids);

    /**
     * 根据id查询事故点信息
     * @param param id
     * @return 事故点信息
     */
    Result<AccidentSpotVo> findById(IdParam param);

    /**
     * 根据条件查询事故点
     * @param conditionParam 条件参数
     * @param pageParam 分页参数
     * @return 事故点信息
     */
    Result<PageVo<AccidentSpotVo>> findByCondition(AccidentSpotConditionParam conditionParam, PageParam pageParam);

    /**
     * 模糊事故点下拉框
     * @param name 事故点名称
     * @return 事故点列表
     */
    Result<PageVo<IdNameVo>> findAccidentList(String name);

    /**
     * 启用一个事故点
     * @param idParam 事故点id
     * @return 是否成功
     */
    Result<String> enable(@Valid IdParam idParam);

    /**
     * 停用一个事故点
     * @param idParam 事故点id
     * @return 是否成功
     */
    Result<String> unEnable(@Valid IdParam idParam);

    /**
     * 批量启用事故点
     * @param ids 事故点id集
     * @return 是否成功
     */
    Result<String> batchEnable(Set<Long> ids);

    /**
     * 批量停用事故点
     * @param ids 事故点集
     * @return 是否成功
     */
    Result<String> batchUnEnable(Set<Long> ids);
}
