/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.rehearsal;

import com.yiring.app.param.rehearsal.EvacuationZoneAddParam;
import com.yiring.app.param.rehearsal.EvacuationZoneConditionParam;
import com.yiring.app.param.rehearsal.EvacuationZoneModifyParam;
import com.yiring.app.vo.IdNameVo;
import com.yiring.app.vo.rehearsal.EvacuationZoneVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import java.util.Set;
import javax.validation.Valid;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/9 10:34
 */
public interface EvacuationZoneService {
    /**
     * 添加一个撤离区信息
     * @param param 撤离区信息
     * @return 是否成功
     */
    Result<String> addOne(EvacuationZoneAddParam param);

    /**
     * 修改一条撤离区信息
     * @param param 撤离区信息
     * @return 是否成功
     */
    Result<String> modifyOne(EvacuationZoneModifyParam param);

    /**
     * 删除一条撤离区信息
     * @param idParam 撤离区信息id
     * @return 是否成功
     */
    Result<String> removeOne(IdParam idParam);

    /**
     * 删除多条撤离区信息
     * @param ids 撤离区id集
     * @return 成功删除了几条
     */
    Result<String> removeMany(Set<Long> ids);

    /**
     * 查询撤离区下拉框
     * @param name 撤离区名称
     * @return 撤离区id和名称
     */
    Result<PageVo<IdNameVo>> findEvacuationPullDown(String name);

    /**
     * 查询一条撤离区信息
     * @param idParam 撤离区id
     * @return 撤离区信息
     */
    Result<EvacuationZoneVo> findOne(IdParam idParam);

    /**
     * 查询撤离区列表
     * @param param 地图id和撤离区名称
     * @return 撤离区信息
     */
    Result<PageVo<EvacuationZoneVo>> findList(EvacuationZoneConditionParam param, PageParam pageParam);

    /**
     * 启用一个撤离区
     * @param idParam 撤离区id
     * @return 是否成功
     */
    Result<String> enable(@Valid IdParam idParam);

    /**
     * 停用一个撤离区
     * @param idParam 撤离区id
     * @return 是否成功
     */
    Result<String> unEnable(@Valid IdParam idParam);

    /**
     * 批量启用撤离区
     * @param ids 撤离区id集
     * @return 启用了几个撤离区
     */
    Result<String> batchEnable(Set<Long> ids);

    /**
     * 批量停用撤离区
     * @param ids 撤离区id集
     * @return 停用了几个撤离区
     */
    Result<String> batchUnEnable(Set<Long> ids);
}
