/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.broadcast;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.domain.broadcast.BroadcastAudio;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 播报音频
 *
 * @author LJ-2204
 * @date 2022/5/7
 */

@ApiModel("BroadcastAudioVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class BroadcastAudioVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 1092099954728361919L;

    @ApiModelProperty(value = "主键", example = "100")
    @JsonSerialize(using = ToStringSerializer.class)
    Long id;

    @ApiModelProperty(value = "语音名称", example = "张三")
    String name;

    @ApiModelProperty(value = "语音地址", example = "uri")
    String uri;

    @ApiModelProperty(value = "上传时间", example = "2022-11-11 22:22:22")
    LocalDateTime uploadTime;

    @ApiModelProperty(value = "备注", example = "1")
    String describe;

    public static BroadcastAudioVo transform(BroadcastAudio broadcastAudio) {
        return BroadcastAudioVo
            .builder()
            .id(broadcastAudio.getId())
            .name(broadcastAudio.getName())
            .uri(broadcastAudio.getUri())
            .uploadTime(broadcastAudio.getUploadTime())
            .describe(broadcastAudio.getDescribe())
            .build();
    }
}
