/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.key;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.domain.key.KeyAlarm;
import com.yiring.app.vo.user.UserVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 按键报警
 *
 * @author LJ-2204
 * @date 2022/5/10
 */

@ApiModel("KeyAlarmVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class KeyAlarmVo implements Serializable {

    @Serial
    private static final long serialVersionUID = -4534979609749122415L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键", example = "111")
    Long id;

    @ApiModelProperty(value = "地图 ID", example = "1")
    Long areaId;

    @ApiModelProperty(value = "用户", example = "111")
    UserVo user;

    @ApiModelProperty(value = "报警时间", example = "2022-11-11 22:22:22")
    LocalDateTime createTime;

    @ApiModelProperty(value = "结束时间", example = "2022-11-11 22:22:22")
    LocalDateTime endTime;

    @ApiModelProperty(value = "报警类型", example = "按键报警")
    String type;

    @ApiModelProperty(value = "报警接收人", example = "张三、李四")
    String receiver;

    @ApiModelProperty(value = "报警状态", example = "T/F")
    Boolean enable;

    public static KeyAlarmVo transform(KeyAlarm keyAlarm) {
        return KeyAlarmVo
            .builder()
            .id(keyAlarm.getId())
            .areaId(keyAlarm.getAreaId())
            .createTime(keyAlarm.getCreateTime())
            .endTime(keyAlarm.getUpdateTime())
            .type("按键报警")
            .enable(keyAlarm.getEnable())
            .build();
    }
}
