/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.location.beacon;

import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.app.domain.location.LocationBeacon;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import lombok.*;
import lombok.experimental.FieldDefaults;
import org.locationtech.jts.geom.Point;

/**
 * 定位信标模型
 *
 * @author LJ-2204
 * @date 2022/4/28
 */

@ApiModel("LocationBeaconVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class LocationBeaconVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 996556953940775577L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键", example = "188354391834")
    Long id;

    @ApiModelProperty(value = "信标", example = "BTI88888888")
    String code;

    @ApiModelProperty(value = "最后一次在线时间", example = "BTI88888888")
    LocalDateTime time;

    @ApiModelProperty(value = "坐标", example = "01010000805C8FC2F528D4734033333333335B7D400000000000000000")
    Point point;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "所属地图", example = "1:总图2:一层3:二层")
    Long areaId;

    public static LocationBeaconVo transform(LocationBeacon locationBeacon) {
        return LocationBeaconVo
            .builder()
            .id(locationBeacon.getId())
            .code(locationBeacon.getCode())
            .time(locationBeacon.getTime())
            .point(locationBeacon.getPoint())
            .areaId(locationBeacon.getAreaId())
            .build();
    }
}
