/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.rehearsal;

import com.yiring.app.domain.rehearsal.AccidentSpot;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.locationtech.jts.geom.Geometry;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/7 11:25
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@ApiModel("事故点VO")
public class AccidentSpotVo implements Serializable {

    @Serial
    private static final long serialVersionUID = -7696351020089245510L;

    @ApiModelProperty(value = "事故点id", example = "1")
    private Long id;

    @ApiModelProperty(value = "事故点名称", example = "事故点1")
    private String name;

    @ApiModelProperty(value = "地图id", example = "1")
    private Long mapId;

    @ApiModelProperty(value = "地图名称", example = "总图")
    private String mapName;

    @ApiModelProperty(value = "空间信息")
    private Geometry geometry;

    @ApiModelProperty(value = "摄像头id", example = "1")
    private Long videoId;

    @ApiModelProperty(value = "摄像头名称", example = "摄像头1")
    private String videoName;

    @ApiModelProperty(value = "超时时间(秒)", example = "100")
    private Integer timeoutDuration;

    @ApiModelProperty(value = "消抖时间(秒)", example = "100")
    private Integer threshold;

    @ApiModelProperty(value = "是否启用(true:启用,false:停用)", example = "true")
    private Boolean enable;

    public static AccidentSpotVo transform(AccidentSpot accidentSpot) {
        return AccidentSpotVo
            .builder()
            .id(accidentSpot.getId())
            .name(accidentSpot.getName())
            .mapId(accidentSpot.getMapId())
            .mapName(accidentSpot.getMapName())
            .geometry(accidentSpot.getGeometry())
            .videoId(accidentSpot.getVideo().getId())
            .videoName(accidentSpot.getVideo().getVideoName())
            .timeoutDuration(accidentSpot.getTimeoutDuration())
            .threshold(accidentSpot.getThreshold())
            .enable(accidentSpot.getEnable())
            .build();
    }
}
