/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.rehearsal;

import com.yiring.app.domain.rehearsal.EvacuationZone;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.locationtech.jts.geom.Geometry;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/9 10:04
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@ApiModel("撤离区VO")
public class EvacuationZoneVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 919152196104921261L;

    @ApiModelProperty(value = "撤离区id", example = "1")
    private Long id;

    @ApiModelProperty(value = "撤离区名称", example = "撤离区1")
    private String name;

    @ApiModelProperty(value = "地图id", example = "1")
    private Long mapId;

    @ApiModelProperty(value = "地图名称", example = "总图")
    private String mapName;

    @ApiModelProperty(value = "空间信息")
    private Geometry geometry;

    @ApiModelProperty(value = "摄像头id", example = "1")
    private Long videoId;

    @ApiModelProperty(value = "摄像头名称", example = "摄像头1")
    private String videoName;

    @ApiModelProperty(value = "超时时间(秒)", example = "100")
    private Integer timeoutDuration;

    @ApiModelProperty(value = "消抖时间(秒)", example = "100")
    private Integer threshold;

    @ApiModelProperty(value = "是否启用(true:启用,false:停用)", example = "true")
    private Boolean enable;

    public static EvacuationZoneVo transform(EvacuationZone evacuationZone) {
        return EvacuationZoneVo
            .builder()
            .id(evacuationZone.getId())
            .name(evacuationZone.getName())
            .mapId(evacuationZone.getMapId())
            .mapName(evacuationZone.getMapName())
            .geometry(evacuationZone.getGeometry())
            .videoId(evacuationZone.getVideo().getId())
            .videoName(evacuationZone.getVideo().getVideoName())
            .timeoutDuration(evacuationZone.getTimeoutDuration())
            .threshold(evacuationZone.getThreshold())
            .enable(evacuationZone.getEnable())
            .build();
    }
}
