/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.broadcast;

import com.yiring.app.param.broadcast.BroadcastAudioAddParam;
import com.yiring.app.param.broadcast.BroadcastAudioFindParam;
import com.yiring.app.param.broadcast.BroadcastAudioModifyParam;
import com.yiring.app.service.broadcast.BroadcastAudioService;
import com.yiring.app.vo.broadcast.BroadcastAudioIndexVo;
import com.yiring.app.vo.broadcast.BroadcastAudioVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.IndexParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 播报音频
 *
 * @author LJ-2204
 * @date 2022/5/7
 */

@Slf4j
@Api(tags = "播报音频")
@Validated
@RestController
@RequestMapping("/broadcast/audio")
public class BroadcastAudioController {

    @Resource
    BroadcastAudioService broadcastAudioService;

    @ApiOperation("添加")
    @PostMapping("save")
    public Result<String> save(@Valid BroadcastAudioAddParam param) {
        return broadcastAudioService.save(param);
    }

    @ApiOperation("删除")
    @DeleteMapping("delete")
    public Result<String> delete(IdParam idParam) {
        return broadcastAudioService.delete(idParam);
    }

    @ApiOperation("修改")
    @PutMapping("modify")
    public Result<String> modify(@Valid BroadcastAudioModifyParam param) {
        return broadcastAudioService.modify(param);
    }

    @ApiOperation("表格查询")
    @GetMapping("page")
    public Result<PageVo<BroadcastAudioVo>> page(@Valid BroadcastAudioFindParam param, PageParam pageParam) {
        return broadcastAudioService.page(param, pageParam);
    }

    @ApiOperation("播报语音检索")
    @GetMapping("index")
    public Result<PageVo<BroadcastAudioIndexVo>> index(IndexParam indexParam) {
        return broadcastAudioService.index(indexParam);
    }

    @ApiOperation("批量下载")
    @GetMapping("download")
    public void download() {}
}
