/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.location.fence;

import com.yiring.app.domain.alarm.AlarmType;
import com.yiring.app.param.location.fence.LocationFenceAddParam;
import com.yiring.app.param.location.fence.LocationFenceConditionParam;
import com.yiring.app.param.location.fence.LocationFenceModifyParam;
import com.yiring.app.service.location.fence.LocationFenceService;
import com.yiring.app.vo.CodeNameVo;
import com.yiring.app.vo.location.fence.LocationFenceSearchVo;
import com.yiring.app.vo.location.fence.LocationFenceVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import java.util.Objects;
import javax.annotation.Resource;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.domain.Sort;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * @author tml
 * @version 1.0
 * @date 2022/4/28 11:50
 */
@RestController
@Api(tags = "Fence(围栏信息)")
@Validated
@Slf4j
@RequestMapping("location/fence")
public class LocationFenceController {

    @Resource
    private LocationFenceService locationFenceService;

    @ApiOperation("添加围栏信息")
    @PostMapping("/addLocationFence")
    public Result<String> addLocationFence(@Valid @RequestBody LocationFenceAddParam param) {
        return locationFenceService.addLocationFence(param);
    }

    @ApiOperation("修改围栏信息")
    @PostMapping("/modifyLocationFence")
    public Result<String> modifyLocationFence(@Valid @RequestBody LocationFenceModifyParam param) {
        return locationFenceService.modifyLocationFence(param);
    }

    @ApiOperation("删除围栏信息")
    @PostMapping("/removeLocationFence")
    public Result<String> removeLocationFence(@Valid IdParam param) {
        return locationFenceService.removeLocationFence(param);
    }

    @ApiOperation("根据条件分页查询围栏信息")
    @PostMapping("/LocationFenceVo")
    public Result<PageVo<LocationFenceVo>> findList(
        @Valid LocationFenceConditionParam conditionParam,
        @Valid PageParam pageParam
    ) {
        if (Objects.isNull(pageParam.getSortField())) {
            pageParam.setSortField(AlarmType.Fields.createTime);
            pageParam.setSortOrder(Sort.Direction.DESC);
        }
        return locationFenceService.findList(conditionParam, pageParam);
    }

    @ApiOperation("根据条id查询围栏信息")
    @PostMapping("/findById")
    public Result<LocationFenceVo> findById(@Valid IdParam param) {
        return locationFenceService.findById(param);
    }

    @ApiOperation("根据围栏名称模糊查询围栏信息")
    @ApiImplicitParam(value = "围栏名称", example = "生产", required = true, name = "name")
    @PostMapping("/findByNameLike")
    public Result<PageVo<LocationFenceSearchVo>> findByNameLike(String name) {
        if (name == null) {
            name = "";
        }
        return locationFenceService.findByNameLike(name);
    }

    @ApiOperation("获取地图下拉框")
    @PostMapping("/findMapList")
    public Result<PageVo<CodeNameVo>> findMapList() {
        return locationFenceService.findMapList();
    }
}
