/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.rehearsal;

import com.yiring.app.param.rehearsal.AccidentSpotAddParam;
import com.yiring.app.param.rehearsal.AccidentSpotConditionParam;
import com.yiring.app.param.rehearsal.AccidentSpotModifyParam;
import com.yiring.app.service.rehearsal.AccidentSpotService;
import com.yiring.app.vo.IdNameVo;
import com.yiring.app.vo.rehearsal.AccidentSpotVo;
import com.yiring.auth.param.IdsParam;
import com.yiring.common.core.Result;
import com.yiring.common.domain.BasicEntity;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import java.util.Objects;
import javax.annotation.Resource;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.domain.Sort;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/7 10:44
 */
@Slf4j
@Validated
@RestController
@Api(tags = "AccidentSpot(事故点管理)")
@RequestMapping("/accident/spot")
public class AccidentSpotController {

    @Resource
    private AccidentSpotService accidentSpotService;

    @ApiOperation(value = "添加一个事故点")
    @PostMapping("/addAccidentSpot")
    public Result<String> addAccidentSpot(@Valid @RequestBody AccidentSpotAddParam param) {
        return accidentSpotService.addAccidentSpot(param);
    }

    @ApiOperation("修改一个事故点")
    @PostMapping("/modifyAccidentSpot")
    public Result<String> modifyAccidentSpot(@Valid @RequestBody AccidentSpotModifyParam param) {
        return accidentSpotService.modifyAccidentSpot(param);
    }

    @ApiOperation("删除一个事故点")
    @PostMapping("/removeAccidentSpot")
    public Result<String> removeAccidentSpot(@Valid IdParam param) {
        return accidentSpotService.removeAccidentSpot(param);
    }

    @ApiOperation("批量删除事故点")
    @PostMapping("/batchRemove")
    public Result<String> batchRemove(@Valid IdsParam idsParam) {
        return accidentSpotService.batchRemove(idsParam.toIds());
    }

    @ApiOperation("根据id查询事故点")
    @GetMapping("/findById")
    public Result<AccidentSpotVo> findById(@Valid IdParam param) {
        return accidentSpotService.findById(param);
    }

    @ApiOperation("根据条件查询事故点")
    @GetMapping("/findByCondition")
    public Result<PageVo<AccidentSpotVo>> findByCondition(
        @Valid AccidentSpotConditionParam conditionParam,
        @Valid PageParam pageParam
    ) {
        if (Objects.isNull(pageParam.getSortField())) {
            pageParam.setSortField(BasicEntity.Fields.createTime);
            pageParam.setSortOrder(Sort.Direction.DESC);
        }
        return accidentSpotService.findByCondition(conditionParam, pageParam);
    }

    @ApiOperation("事故点名下拉框")
    @ApiImplicitParam(value = "事故点名(全模糊)", name = "name", example = "事故", required = true)
    @GetMapping("/findAccidentList")
    public Result<PageVo<IdNameVo>> findAccidentList(String name) {
        if (name == null) {
            name = "";
        }
        return accidentSpotService.findAccidentList(name);
    }

    @ApiOperation("启用一个事故点")
    @PostMapping("/enable")
    public Result<String> enable(@Valid IdParam idParam) {
        return accidentSpotService.enable(idParam);
    }

    @ApiOperation("停用一个事故点")
    @PostMapping("/unEnable")
    public Result<String> unEnable(@Valid IdParam idParam) {
        return accidentSpotService.unEnable(idParam);
    }

    @ApiOperation("批量启用")
    @PostMapping("/batchEnable")
    public Result<String> batchEnable(@Valid IdsParam idsParam) {
        return accidentSpotService.batchEnable(idsParam.toIds());
    }

    @ApiOperation("批量停用")
    @PostMapping("/batchUnEnable")
    public Result<String> batchUnEnable(@Valid IdsParam idsParam) {
        return accidentSpotService.batchUnEnable(idsParam.toIds());
    }
}
