/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.rehearsal;

import com.yiring.app.param.rehearsal.EvacuationZoneAddParam;
import com.yiring.app.param.rehearsal.EvacuationZoneConditionParam;
import com.yiring.app.param.rehearsal.EvacuationZoneModifyParam;
import com.yiring.app.service.rehearsal.EvacuationZoneService;
import com.yiring.app.vo.IdNameVo;
import com.yiring.app.vo.rehearsal.EvacuationZoneVo;
import com.yiring.auth.param.IdsParam;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.validation.Valid;
import org.springframework.web.bind.annotation.*;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/9 10:19
 */
@Api(tags = "EvacuationZone(撤离区)")
@RestController
@RequestMapping("/evacuation/zone")
public class EvacuationZoneController {

    @Resource
    private EvacuationZoneService evacuationZoneService;

    @ApiOperation("添加一条撤离区信息")
    @PostMapping("/addOne")
    public Result<String> addOne(@Valid @RequestBody EvacuationZoneAddParam param) {
        return evacuationZoneService.addOne(param);
    }

    @ApiOperation("修改一条撤离区信息")
    @PostMapping("/modifyOne")
    public Result<String> modifyOne(@Valid @RequestBody EvacuationZoneModifyParam param) {
        return evacuationZoneService.modifyOne(param);
    }

    @ApiOperation("删除一条撤离区信息")
    @PostMapping("removeOne")
    public Result<String> removeOne(@Valid IdParam idParam) {
        return evacuationZoneService.removeOne(idParam);
    }

    @ApiOperation("批量删除撤离区信息")
    @PostMapping("/removeMany")
    public Result<String> removeMany(@Valid IdsParam idsParam) {
        return evacuationZoneService.removeMany(idsParam.toIds());
    }

    @ApiOperation("查询撤离区下拉框")
    @GetMapping("/findEvacuationPullDown")
    public Result<PageVo<IdNameVo>> findEvacuationPullDown(String name) {
        if (name == null) {
            name = "";
        }
        return evacuationZoneService.findEvacuationPullDown(name);
    }

    @ApiOperation("查询一条撤离区信息")
    @GetMapping("/findOne")
    public Result<EvacuationZoneVo> findOne(@Valid IdParam idParam) {
        return evacuationZoneService.findOne(idParam);
    }

    @ApiOperation("查询撤离区信息列表")
    @GetMapping("/findList")
    public Result<PageVo<EvacuationZoneVo>> findList(
        @Valid EvacuationZoneConditionParam conditionParam,
        @Valid PageParam pageParam
    ) {
        return evacuationZoneService.findList(conditionParam, pageParam);
    }

    @ApiOperation("启用一个撤离区")
    @PostMapping("/enable")
    public Result<String> enable(@Valid IdParam idParam) {
        return evacuationZoneService.enable(idParam);
    }

    @ApiOperation("停用一个撤离区")
    @PostMapping("/unEnable")
    public Result<String> unEnable(@Valid IdParam idParam) {
        return evacuationZoneService.unEnable(idParam);
    }

    @ApiOperation("批量启用撤离区")
    @PostMapping("/batchEnable")
    public Result<String> batchEnable(@Valid IdsParam idsParam) {
        return evacuationZoneService.batchEnable(idsParam.toIds());
    }

    @ApiOperation("批量停用撤离区")
    @PostMapping("/batchUnEnable")
    public Result<String> batchUnEnable(@Valid IdsParam idsParam) {
        return evacuationZoneService.batchUnEnable(idsParam.toIds());
    }
}
