/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.user;

import com.yiring.app.param.user.*;
import com.yiring.app.service.user.UserAppService;
import com.yiring.app.vo.user.UserInfoVo;
import com.yiring.app.vo.user.UserVo;
import com.yiring.auth.param.IdsParam;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.IndexParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

/**
 * 用户信息
 *
 * @author Jim
 * @version 0.1
 * 2022/1/24 14:13
 */

@Slf4j
@Validated
@Api(tags = "人员管理")
@RestController
@RequestMapping("/user/app/")
public class UserAppController {

    @Resource
    UserAppService userService;

    @ApiOperation("表格查询")
    @GetMapping("findUserPage")
    public Result<PageVo<UserVo>> findUserPage(@Valid UserFindParam userFindParam, @Valid PageParam pageParam) {
        return userService.findUserPage(userFindParam, pageParam);
    }

    @ApiOperation("用户详细信息查询")
    @GetMapping("findUserById")
    public Result<UserInfoVo> findUserById(@Valid IdParam idParam) {
        return userService.findUserById(idParam);
    }

    @ApiOperation("给用户分配标签卡")
    @PutMapping("userBingTag")
    public Result<String> userBingTag(@Valid UserBingTagParam userBingTagParam) {
        return userService.userBingTag(userBingTagParam);
    }

    @ApiOperation("收卡")
    @PutMapping("userUnBingTag")
    public Result<String> userUnBingTag(@Valid IdsParam idsParam) {
        return userService.userUnBingTag(idsParam);
    }

    @ApiOperation("逻辑删除用户")
    @DeleteMapping("deleteUser")
    public Result<String> deleteUser(@Valid IdsParam idsParam) {
        return userService.deleteUser(idsParam);
    }

    @ApiOperation("用户导出")
    @GetMapping("exportUser")
    public void exportUser(@Valid UserFindParam userFindParam, HttpServletResponse response) {
        userService.exportUser(userFindParam, response);
    }

    @ApiOperation("启用/停用")
    @PutMapping("stateUser")
    public Result<String> stateUser(@Valid IdParam idParam) {
        return userService.stateUser(idParam);
    }

    @ApiOperation("编辑用户")
    @PutMapping("modifyUser")
    public Result<String> modifyUser(@Valid UserModifyParam userModifyParam) {
        return userService.modifyUser(userModifyParam);
    }

    @ApiOperation("新增用户")
    @PostMapping("addUser")
    public Result<String> addUser(@Valid UserAddParam userAddParam) {
        return userService.addUser(userAddParam);
    }

    @ApiOperation("导入")
    @PostMapping("importUser")
    public Result<String> importUser(@RequestParam("file") MultipartFile file) {
        return userService.importUser(file);
    }

    @ApiOperation("用户信息检索")
    @GetMapping("indexUser")
    public Result<PageVo<UserVo>> indexUser(@Valid IndexParam indexParam) {
        return userService.indexUser(indexParam);
    }

    @ApiOperation("条件查询")
    @GetMapping("findUser")
    public Result<PageVo<UserVo>> findUser(@Valid UserFindParam userFindParam) {
        return userService.findUser(userFindParam);
    }

    @ApiOperation("批量发卡")
    @PutMapping("batchSendCard")
    public Result<String> batchSendCard(@RequestParam("file") MultipartFile file) {
        return userService.batchSendCard(file);
    }
}
