/* (C) 2022 YiRing, Inc. */
package com.yiring.auth.param.user;

import cn.hutool.core.convert.Convert;
import cn.hutool.core.util.ObjectUtil;
import com.yiring.auth.domain.dept.Department;
import com.yiring.auth.domain.post.Post;
import com.yiring.auth.domain.role.Role;
import com.yiring.auth.domain.user.User;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.util.HashSet;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 用户新增参数
 *
 * @author LJ-2204
 * @date 2022/5/10
 */

@ApiModel("UserAddParam")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class UserSaveParam implements Serializable {

    @Serial
    private static final long serialVersionUID = 2256725474621511610L;

    @ApiModelProperty(value = "用户昵称", example = "张三", required = true)
    @NotEmpty(message = "用户昵称不能为空")
    String realName;

    @ApiModelProperty(value = "手机号码", example = "1888888888")
    String mobile;

    @ApiModelProperty(value = "用户名称", example = "admin", required = true)
    @NotEmpty(message = "用户名称不能为空")
    String username;

    @ApiModelProperty(value = "性别", example = "0/1")
    Boolean gender;

    @ApiModelProperty(value = "职位", example = "100")
    Long postId;

    @ApiModelProperty(value = "归属部门", example = "1", required = true)
    @NotNull(message = "归属部门不能为空")
    Long deptId;

    @ApiModelProperty(value = "邮箱", example = "zhansan@163.com")
    String email;

    @ApiModelProperty(value = "用户密码", example = "*******", required = true)
    @NotEmpty(message = "用户密码不能为空")
    String password;

    @ApiModelProperty(value = "状态", example = "0/1")
    Boolean enabled;

    @ApiModelProperty(value = "角色id", example = "1,2,3", required = true)
    @NotEmpty(message = "角色id不能为空")
    String roles;

    @ApiModelProperty(value = "备注", example = "请输入备注")
    String introduction;

    public static User transform(UserSaveParam param) {
        User user = User
            .builder()
            .realName(param.getRealName())
            .mobile(param.getMobile())
            .username(param.getUsername())
            .gender(param.getGender())
            .department(Department.builder().id(param.getDeptId()).build())
            .email(param.getEmail())
            .password(param.getPassword())
            .enabled(param.getEnabled())
            .introduction(param.getIntroduction())
            .build();

        if (ObjectUtil.isNotEmpty(param.getPostId())) {
            user.setPost(Post.builder().id(param.getPostId()).build());
        }

        if (ObjectUtil.isNotEmpty(param.getRoles())) {
            String[] split = param.getRoles().split(",");
            Long[] roles = Convert.toLongArray(split);
            HashSet<Role> hashSet = new HashSet<>();
            for (Long role : roles) {
                hashSet.add(Role.builder().id(role).build());
            }
            user.setRoles(hashSet);
        }

        return user;
    }
}
