/* (C) 2022 YiRing, Inc. */
package com.yiring.auth.service.user.impl;

import cn.hutool.core.collection.ListUtil;
import cn.hutool.core.convert.Convert;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.yiring.auth.domain.user.User;
import com.yiring.auth.domain.user.UserRepository;
import com.yiring.auth.param.user.UserFindParam;
import com.yiring.auth.param.user.UserSaveParam;
import com.yiring.auth.service.user.UserService;
import com.yiring.auth.vo.user.UserVo;
import com.yiring.common.core.Result;
import com.yiring.common.domain.BasicEntity;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import java.util.List;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.Order;
import javax.persistence.criteria.Predicate;
import lombok.extern.slf4j.Slf4j;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * 部门信息控制器
 *
 * @author LJ-2204
 * @date 2022/5/10
 */

@Transactional(rollbackFor = RuntimeException.class)
@Service
@Slf4j
public class UserServiceImpl implements UserService {

    @Resource
    UserRepository userRepository;

    @Override
    public Result<String> add(UserSaveParam param) {
        userRepository.save(UserSaveParam.transform(param));
        return Result.ok();
    }

    @Override
    public Result<PageVo<UserVo>> page(UserFindParam param, PageParam pageParam) {
        Specification<User> specification = (root, cq, cb) -> {
            List<Predicate> predicates = ListUtil.toList();

            predicates.add(cb.isNotNull(root.get(User.Fields.username)));

            if (StrUtil.isNotEmpty(param.getRealName())) {
                predicates.add(cb.like(root.get(User.Fields.realName), "%" + param.getRealName() + "%"));
            }

            if (ObjectUtil.isNotEmpty(param.getDeptId())) {
                predicates.add(
                    cb.equal(root.get(User.Fields.department).get(BasicEntity.Fields.id), param.getDeptId())
                );
            }

            if (ObjectUtil.isNotEmpty(param.getRoles())) {
                CriteriaBuilder.In<Object> in = cb.in(root.get(User.Fields.post).get(BasicEntity.Fields.id));
                String[] split = param.getRoles().split(",");
                Long[] roles = Convert.toLongArray(split);
                for (Long role : roles) in.value(role);
                predicates.add(cb.and(in));
            }

            Order order = cb.desc(root.get(BasicEntity.Fields.createTime));

            return cq.orderBy(order).where(predicates.toArray(new Predicate[0])).getRestriction();
        };

        // 分页
        Pageable pageable = PageRequest.of(pageParam.getPageNo() - 1, pageParam.getPageSize());
        Page<User> users = userRepository.findAll(specification, pageable);
        List<UserVo> userVos = users.getContent().stream().map(UserVo::transform).collect(Collectors.toList());
        PageVo<UserVo> pageVo = PageVo.build(userVos, users.getTotalElements());
        return Result.ok(pageVo);
    }
}
