/* (C) 2022 YiRing, Inc. */
package com.yiring.auth.vo.user;

import cn.hutool.core.util.ObjectUtil;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.auth.domain.user.User;
import com.yiring.auth.vo.role.RoleVo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.Set;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 用户信息
 * @author ifzm
 * 2022/03/03 10:35
 **/

@ApiModel("UserVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class UserVo implements Serializable {

    @Serial
    private static final long serialVersionUID = -2184378273450466835L;

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键", example = "1")
    Long id;

    @ApiModelProperty(value = "姓名", example = "张三")
    String realName;

    @ApiModelProperty(value = "工号", example = "1234566")
    String uuid;

    @ApiModelProperty(value = "部门ID", example = "100")
    Long deptId;

    @ApiModelProperty(value = "部门名称", example = "研发")
    String deptName;

    @ApiModelProperty(value = "手机号", example = "13012345678")
    String mobile;

    @ApiModelProperty(value = "角色", example = "系统管理员")
    Set<RoleVo> roles;

    @ApiModelProperty(value = "最后登录时间", example = "2022-10-24 10:24:00")
    LocalDateTime lastLoginTime;

    @ApiModelProperty(value = "状态", example = "true")
    Boolean enabled;

    public static UserVo transform(User user) {
        UserVo userVo = UserVo
            .builder()
            .id(user.getId())
            .realName(user.getRealName())
            .uuid(user.getUuid())
            .mobile(user.getMobile())
            .lastLoginTime(user.getLastLoginTime())
            .enabled(user.getEnabled())
            .deptName(user.getDepartment().getName())
            .deptId(user.getDepartment().getId())
            .build();

        if (ObjectUtil.isNotEmpty(user.getRoles())) {}

        return userVo;
    }
}
